@@ -7,7 +7,8 @@ def test_basic():
 
 def test_consts():
     print(m.consts)
-    print(f'THOST_TERT_QUICK: {m.consts.THOST_TERT_QUICK}')
+    print(f'THOST_FTDC_EXP_Normal: {m.consts.THOST_FTDC_EXP_Normal}')
+    print(f'THOST_FTDC_ICT_TaxNo: {m.consts.THOST_FTDC_ICT_TaxNo}')
 
 
 if __name__ == '__main__':
